@@ -31,7 +31,7 @@ class PyMomMessage:
             id = str(uuid.uuid4())
 
         wrapper = dict()
-        wrapper['id'] = str(correlation_id)
+        wrapper['id'] = str(id)
         wrapper['event_type'] = self.event_type
         wrapper['version'] = self.version
         wrapper['timestamp'] = str(datetime.datetime.now())
