@@ -19,10 +19,9 @@ class PyMomMonitor(PyMomAbstractConsumer):
 
     def on_message(self,message):
         """ Process messages. """
-        correlation_id = message['correlation_id']
+        id = message['id']
         payload = message['payload']
-        self.logger.info("Received message:  ({}) {}"
-                         .format(correlation_id,payload))
+        self.logger.info("Received message:  ({}) {}".format(id,payload))
 
 
 if __name__ == "__main__":
